@@ -13,9 +13,7 @@ The code in this file is mainly lifted out of cmd.py in Python 2.2, with minor
 changes. Licensing should therefore be under the standard Python terms.  For
 details on the PSF (Python Software Foundation) standard license, see:
 
-http://www.python.org/2.2.3/license.html
-
-$Id: Debugger.py 2913 2007-12-31 12:42:14Z vivainio $"""
+http://www.python.org/2.2.3/license.html"""
 
 #*****************************************************************************
 #
@@ -27,10 +25,6 @@ $Id: Debugger.py 2913 2007-12-31 12:42:14Z vivainio $"""
 #
 #*****************************************************************************
 
-from IPython import Release
-__author__  = '%s <%s>' % Release.authors['Fernando']
-__license__ = 'Python'
-
 import bdb
 import cmd
 import linecache
@@ -39,7 +33,7 @@ import sys
 
 from IPython import PyColorize, ColorANSI, ipapi
 from IPython.genutils import Term
-from IPython.excolors import ExceptionColors
+from IPython.excolors import exception_colors
 
 # See if we can use pydb.
 has_pydb = False
@@ -210,7 +204,7 @@ class Pdb(OldPdb):
 
             # Create color table: we copy the default one from the traceback
             # module and add a few attributes needed for debugging
-            self.color_scheme_table = ExceptionColors.copy()
+            self.color_scheme_table = exception_colors()
 
             # shorthands 
             C = ColorANSI.TermColors
@@ -257,8 +251,7 @@ class Pdb(OldPdb):
 
             # Create color table: we copy the default one from the traceback
             # module and add a few attributes needed for debugging
-            ExceptionColors.set_active_scheme(color_scheme)
-            self.color_scheme_table = ExceptionColors.copy()
+            self.color_scheme_table = exception_colors()
 
             # shorthands 
             C = ColorANSI.TermColors
@@ -334,9 +327,10 @@ class Pdb(OldPdb):
         print >>Term.cout, self.format_stack_entry(frame_lineno, '', context)
 
         # vds: >>
-        frame, lineno = frame_lineno
-        filename = frame.f_code.co_filename
-        __IPYTHON__.hooks.synchronize_with_editor(filename, lineno, 0)
+        if hasattr(__IPYTHON__.hooks, 'synchronize_with_editor'):
+            frame, lineno = frame_lineno
+            filename = frame.f_code.co_filename
+            __IPYTHON__.hooks.synchronize_with_editor(filename, lineno, 0)
         # vds: <<
 
     def format_stack_entry(self, frame_lineno, lprefix=': ', context = 3):
@@ -503,9 +497,10 @@ class Pdb(OldPdb):
         self.print_list_lines(self.curframe.f_code.co_filename, first, last)
 
         # vds: >>
-        lineno = first
-        filename = self.curframe.f_code.co_filename
-        __IPYTHON__.hooks.synchronize_with_editor(filename, lineno, 0)
+        if hasattr(__IPYTHON__.hooks, 'synchronize_with_editor'):
+            lineno = first
+            filename = self.curframe.f_code.co_filename
+            __IPYTHON__.hooks.synchronize_with_editor(filename, lineno, 0)
         # vds: <<
 
     do_l = do_list
@@ -527,3 +522,36 @@ class Pdb(OldPdb):
         namespaces = [('Locals', self.curframe.f_locals),
                       ('Globals', self.curframe.f_globals)]
         __IPYTHON__.magic_pinfo("pinfo %s" % arg, namespaces=namespaces)
+
+    def checkline(self, filename, lineno):
+        """Check whether specified line seems to be executable.
+
+        Return `lineno` if it is, 0 if not (e.g. a docstring, comment, blank
+        line or EOF). Warning: testing is not comprehensive.
+        """
+        #######################################################################
+        # XXX Hack!  Use python-2.5 compatible code for this call, because with
+        # all of our changes, we've drifted from the pdb api in 2.6.  For now,
+        # changing:
+        #
+        #line = linecache.getline(filename, lineno, self.curframe.f_globals)
+        # to:
+        #
+        line = linecache.getline(filename, lineno)
+        #
+        # does the trick.  But in reality, we need to fix this by reconciling
+        # our updates with the new Pdb APIs in Python 2.6.
+        #
+        # End hack.  The rest of this method is copied verbatim from 2.6 pdb.py
+        #######################################################################
+        
+        if not line:
+            print >>self.stdout, 'End of file'
+            return 0
+        line = line.strip()
+        # Don't allow setting breakpoint at a blank line
+        if (not line or (line[0] == '#') or
+             (line[:3] == '"""') or line[:3] == "'''"):
+            print >>self.stdout, '*** Blank or comment'
+            return 0
+        return lineno
