@@ -24,7 +24,12 @@ from zope.interface import Interface, implements
 from twisted.internet import defer
 from twisted.python import components, failure, log
 
-from foolscap import Referenceable
+try:
+    # This is preferred in foolscap v > 0.4.3
+    from foolscap.api import Referenceable
+except ImportError:
+    # Fallback for older versions
+    from foolscap import Referenceable
 
 from IPython.kernel import error 
 from IPython.kernel.util import printer
@@ -131,7 +136,7 @@ class FCSynchronousMultiEngineFromMultiEngine(Referenceable):
     def _addDeferredIDCallback(self, did, callback, *args, **kwargs):
         self._deferredIDCallbacks[did] = (callback, args, kwargs)
         return did
-        
+    
     #---------------------------------------------------------------------------
     # IEngineMultiplexer related methods
     #---------------------------------------------------------------------------
@@ -346,7 +351,7 @@ class FCFullSynchronousMultiEngineClient(object):
     #---------------------------------------------------------------------------
     # IEngineMultiplexer related methods
     #---------------------------------------------------------------------------
-        
+    
     def execute(self, lines, targets='all', block=True):
         d = self.remote_reference.callRemote('execute', lines, targets, block)
         d.addCallback(self.unpackage)
