@@ -5,8 +5,7 @@ Readline is used throughout IPython as 'import IPython.rlineimpl as readline'.
 
 In addition to normal readline stuff, this module provides have_readline
 boolean and _outputfile variable used in genutils.
-
-$Id: Magic.py 1096 2006-01-28 20:08:02Z vivainio $"""
+"""
 
 import sys
 
@@ -34,7 +33,19 @@ if sys.platform == 'win32' and have_readline:
 uses_libedit = False
 if sys.platform == 'darwin' and have_readline:
     import commands
-    (status, result) = commands.getstatusoutput( "otool -L %s | grep libedit" % _rl.__file__ )
+    # Boyd's patch had a 'while True' here, I'm always a little worried about
+    # infinite loops with such code, so for now I'm taking a more conservative
+    # approach. See https://bugs.launchpad.net/ipython/+bug/411599.
+    for i in range(10):
+        try:
+            (status, result) = commands.getstatusoutput( "otool -L %s | grep libedit" % _rl.__file__ )
+            break
+        except IOError, (errno, strerror):
+            if errno == 4:
+                continue
+            else:
+                break
+
     if status == 0 and len(result) > 0:
         # we are bound to libedit - new in Leopard
         _rl.parse_and_bind("bind ^I rl_complete")
@@ -53,4 +64,4 @@ if have_readline:
         _rl.clear_history
     except AttributeError:
         def clear_history(): pass
-        _rl.clear_history = clear_history
\ No newline at end of file
+        _rl.clear_history = clear_history
